@@ -46,7 +46,6 @@ class AudioProcess:
             waveform = self.transforms(waveform)
 
         wav_dest_path = f"{self.path_prefix}.wav"
-        print(wav_dest_path)
         torchaudio.save(wav_dest_path, waveform, rate)
 
         self.wav_dest_path = wav_dest_path
@@ -102,12 +101,12 @@ class AudioWebDatasetPreprocess:
 
     async def preprocess(self):
         urls, path = self.urls, self.root
-        tarfile_name = os.path.join(path, f"{self.name}.tar.gz")
+        tarfile_name = os.path.join(path, f"{self.name}.tar")
         waveform_id = 0
 
         async with Downloader(urls, path=path) as files:
-            async with Decompressor(files, path=path) as folders:
-                with tarfile.open(tarfile_name, "w:gz") as archive:
+            async with Decompressor(files, path=path, remove_on_exit=True) as folders:
+                with tarfile.open(tarfile_name, "w") as archive:
                     for folder in tqdm(folders):
                         for wav in tqdm(glob.glob(folder + "/**/*.wav")):
                             waveform, rate = torchaudio.load(wav)
